; docformat = 'rst'
;+
; This is an example program to demontrate how to create a box and whisker plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "box_whisker_plot.pro" and run it like this::
;       IDL> .RUN box_whisker_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Box_Whisker_Plot
 
   ; Open and read the Mickelson-Morley speed of light data.
   OpenR, lun, 'mm_data.dat', /Get_Lun
   header = Strarr(2)
   Readf, lun, header
   data = Intarr(5, 20)
   Readf, lun, data
   Free_Lun, lun
   
   ; Draw the plot.
   cgBoxPlot, data, XTitle='Experiment Number', $
      YTitle='Speed of Light (km/s minus 299,000)', $
      /FillBoxes, BoxColor='plum', AxisColor='black', $
      OutLineColor='navy', OutlierColor='grn5'
      
   ; Draw a red line at the true speed of light.
   cgPlotS, !X.CRange, [792.458,792.458], Color='red', Thick=2
   cgText, 3, 770, /Data, Color='red', 'True Speed', Alignment=0.5    
   
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Box_Whisker_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Box_Whisker_Plot', WBackground='White', $
     WTitle='Box and Whisker Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'box_whisker_plot.ps'
  Box_Whisker_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'box_whisker_plot.ps', /PNG, Width=600

END